@@ -2,7 +2,7 @@ import os
 import sys
 import logging
 from collections import OrderedDict, namedtuple
-from typing import Dict
+from typing import Dict, List, Tuple
 
 from entrypoints import EntryPoint
 
@@ -10,12 +10,12 @@ TASKS_DIRECTORY = "firex_tasks_directory"
 
 logger = logging.getLogger(__name__)
 
-_loaded_firex_bundles = None
+_loaded_firex_bundles = {}
 
 
-class PkgVersionInfo(namedtuple('PkgVersionInfo', ['pkg', 'version'])):
+class PkgVersionInfo(namedtuple('PkgVersionInfo', ('pkg', 'version', 'commit'), defaults=(None, None, None))):
     def __str__(self):
-        return f'{self.pkg}: {self.version}'
+        return f'{self.pkg}: {self.version or self.commit}'
 
 
 def _get_paths_without_cwd() -> [str]:
@@ -50,24 +50,27 @@ def prune_duplicate_module_entry_points(entry_points) -> [EntryPoint]:
     return list(id_to_entry_points.values())
 
 
-def _get_entrypoints(name, prune_duplicates=True) -> [EntryPoint]:
+def _get_entrypoints(name, prune_duplicates=True, path=None) -> [EntryPoint]:
     import entrypoints
-    eps = [ep for ep in entrypoints.get_group_all(name)]
+    if path is not None and not isinstance(path, list):
+        path = [path]
+    eps = [ep for ep in entrypoints.get_group_all(name, path=path)]
     if prune_duplicates:
         eps = prune_duplicate_module_entry_points(eps)
     return eps
 
 
-def get_firex_bundles_entry_points() -> [EntryPoint]:
-    return _get_entrypoints('firex.bundles')
+def get_firex_bundles_entry_points(path=None) -> [EntryPoint]:
+    return _get_entrypoints('firex.bundles', path=path)
 
 
-def loaded_firex_bundles_entry_points() -> Dict[EntryPoint, object]:
+def loaded_firex_bundles_entry_points(path=None) -> Dict[EntryPoint, object]:
     global _loaded_firex_bundles
-    if _loaded_firex_bundles is None:
-        eps = get_firex_bundles_entry_points()
-        _loaded_firex_bundles = {ep: ep.load() for ep in eps}
-    return _loaded_firex_bundles
+    key = str(path)
+    if key not in _loaded_firex_bundles:
+        eps = get_firex_bundles_entry_points(path=path)
+        _loaded_firex_bundles[key] = {ep: ep.load() for ep in eps}
+    return _loaded_firex_bundles[key]
 
 
 def get_firex_tracking_services_entry_points() -> [EntryPoint]:
@@ -80,11 +83,32 @@ def get_firex_dependant_package_versions() -> [PkgVersionInfo]:
         try:
             version = loaded_pkg.__version__
         except AttributeError:
-            version = 'None'
-        versions.append(PkgVersionInfo(pkg=ep.name, version=version))
+            version = None
+        try:
+            commit = loaded_pkg._version.get_versions()['full-revisionid']
+        except AttributeError:
+            commit = None
+        versions.append(PkgVersionInfo(pkg=ep.name, version=version, commit=commit))
     return versions
 
 
+def get_all_pkg_versions() -> [PkgVersionInfo]:
+    import firexkit
+    import firexapp
+    from firexapp.submit.tracking_service import get_tracking_services_versions
+    return [
+               PkgVersionInfo(pkg='firexkit',
+                              version=firexkit.__version__,
+                              commit=firexkit._version.get_versions()['full-revisionid']),
+               PkgVersionInfo(pkg='firexapp',
+                              version=firexapp.__version__,
+                              commit=firexapp._version.get_versions()['full-revisionid']),
+    ] + get_tracking_services_versions() + get_firex_dependant_package_versions()
+
+
+def get_all_pkg_versions_as_dict() -> dict():
+    return {pkg_info.pkg: pkg_info for pkg_info in get_all_pkg_versions()}
+
 def _find_bundle_pkg_root(path, namespace):
     while True:
         head, tail = os.path.split(path)
@@ -94,15 +118,18 @@ def _find_bundle_pkg_root(path, namespace):
             path = os.path.dirname(path)
 
 
-def _get_firex_bundle_package_locations() -> [str]:
+# Return a list of two-element tuples
+# Where the 1st element is the path of package
+# and the 2nd element is the path of package's root
+def _get_firex_bundle_package_locations(path=None) -> List[Tuple[str, str]]:
     locations = []
-    loaded_entry_points = loaded_firex_bundles_entry_points()
+    loaded_entry_points = loaded_firex_bundles_entry_points(path=path)
     for p in loaded_entry_points.values():
         namespace = p.__package__.split('.')[0]
-        paths = p.__path__
-        for path in paths:
-            root = _find_bundle_pkg_root(path, namespace)
-            locations.append((path, root))
+        pkg_paths = p.__path__
+        for pkg_path in pkg_paths:
+            root = _find_bundle_pkg_root(pkg_path, namespace)
+            locations.append((pkg_path, root))
     return locations
 
 
