@@ -184,6 +184,7 @@ class SubmitBaseApp:
         finally:
             if args.tracking_services_wait_release_console:
                 self.wait_tracking_services_release_console_ready()
+            logger.debug('Copying submit log one final time and exiting')
             self.copy_submission_log()
 
     @staticmethod
@@ -336,6 +337,7 @@ class SubmitBaseApp:
 
         app.conf.result_backend = broker_url
         app.conf.broker_url = broker_url
+        app.conf.mc = BrokerFactory.get_hostname_port_from_url(broker_url)[0]
 
     def start_engine(self, args, chain_args, uid) -> {}:
         # Start Broker
